@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import datetime
 
 
@@ -13,19 +10,19 @@ class UTC(datetime.tzinfo):
         return datetime.timedelta(0)
 
     def tzname(self, dt):
-        return str('UTC')
+        return "UTC"
 
     def dst(self, dt):
         return datetime.timedelta(0)
 
     def __repr__(self):
-        return str('<UTC>')
+        return "<UTC>"
 
     def __str__(self):
-        return str('UTC')
+        return "UTC"
 
     def __unicode__(self):
-        return 'UTC'
+        return "UTC"
 
 
 def json_to_datetime(date):
@@ -38,5 +35,6 @@ def json_to_datetime(date):
     :returns: A timezone aware datetime object.
     :rtype: :class:`datetime.datetime`
     """
-    return datetime.datetime.strptime(date, '%Y-%m-%dT%H:%M:%S.%fZ').replace(
-        tzinfo=UTC())
+    return datetime.datetime.strptime(date, "%Y-%m-%dT%H:%M:%S.%fZ").replace(
+        tzinfo=UTC()
+    )
