@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import datetime
 import json
 import logging
@@ -10,7 +7,7 @@ from pypuppetdb.errors import APIError
 log = logging.getLogger(__name__)
 
 
-class BinaryOperator(object):
+class BinaryOperator:
     """
     This is a parent helper class used to create PuppetDB AST queries
     for single key-value pairs for the available operators.
@@ -42,7 +39,7 @@ class BinaryOperator(object):
         self.data = [operator, field, value]
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -51,7 +48,7 @@ class BinaryOperator(object):
         return self.data
 
 
-class BooleanOperator(object):
+class BooleanOperator:
     """
     This is a parent helper class used to create PuppetDB AST queries
     for available boolean queries.
@@ -79,15 +76,15 @@ class BooleanOperator(object):
                 self.add(i)
         elif type(query) == str:
             self.operations.append(json.loads(query))
-        elif isinstance(query, (BinaryOperator, InOperator,
-                                BooleanOperator)):
+        elif isinstance(query, (BinaryOperator, InOperator, BooleanOperator)):
             self.operations.append(query.json_data())
         else:
-            raise APIError("Can only accept fixed-string queries, arrays " +
-                           "or operator objects")
+            raise APIError(
+                "Can only accept fixed-string queries, arrays " + "or operator objects"
+            )
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -98,7 +95,7 @@ class BooleanOperator(object):
         return [self.operator] + self.operations
 
 
-class ExtractOperator(object):
+class ExtractOperator:
     """
     Queries that either do not or cannot require all the key-value pairs
     from an endpoint can use the Extract Operator as described in
@@ -123,21 +120,23 @@ class ExtractOperator(object):
         elif isinstance(field, FunctionOperator):
             self.fields.append(field.json_data())
         else:
-            raise APIError("ExtractOperator.add_field only supports "
-                           "lists and strings")
+            raise APIError(
+                "ExtractOperator.add_field only supports " "lists and strings"
+            )
 
     def add_query(self, query):
         if self.query is not None:
             raise APIError("Only one query is supported by ExtractOperator")
         elif isinstance(query, str):
             self.query = json.loads(query)
-        elif isinstance(query, (BinaryOperator, SubqueryOperator,
-                                BooleanOperator)):
+        elif isinstance(query, (BinaryOperator, SubqueryOperator, BooleanOperator)):
             self.query = query.json_data()
         else:
-            raise APIError("ExtractOperator.add_query only supports "
-                           "strings, BinaryOperator, BooleanOperator "
-                           "and SubqueryOperator objects")
+            raise APIError(
+                "ExtractOperator.add_query only supports "
+                "strings, BinaryOperator, BooleanOperator "
+                "and SubqueryOperator objects"
+            )
 
     def add_group_by(self, field):
         if isinstance(field, list):
@@ -145,18 +144,20 @@ class ExtractOperator(object):
                 self.add_group_by(i)
         elif isinstance(field, str):
             if len(self.group_by) == 0:
-                self.group_by.append('group_by')
+                self.group_by.append("group_by")
             self.group_by.append(field)
         elif isinstance(field, FunctionOperator):
             if len(self.group_by) == 0:
-                self.group_by.append('group_by')
+                self.group_by.append("group_by")
             self.group_by.append(field.json_data())
         else:
-            raise APIError("ExtractOperator.add_group_by only supports "
-                           "lists, strings, and FunctionOperator objects")
+            raise APIError(
+                "ExtractOperator.add_group_by only supports "
+                "lists, strings, and FunctionOperator objects"
+            )
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -165,7 +166,7 @@ class ExtractOperator(object):
         if len(self.fields) == 0:
             raise APIError("ExtractOperator needs at least one field")
 
-        arr = ['extract', self.fields]
+        arr = ["extract", self.fields]
 
         if self.query is not None:
             arr.append(self.query)
@@ -175,7 +176,7 @@ class ExtractOperator(object):
         return arr
 
 
-class FunctionOperator(object):
+class FunctionOperator:
     """
     Performs an aggregate function on the result of a subquery, full
     documentation is available at
@@ -191,24 +192,23 @@ class FunctionOperator(object):
     """
 
     def __init__(self, function, field=None, fmt=None):
-        if function not in ['count', 'avg', 'sum', 'min', 'max', 'to_string']:
-            raise APIError("Unsupport function: {0}".format(function))
+        if function not in ["count", "avg", "sum", "min", "max", "to_string"]:
+            raise APIError(f"Unsupport function: {function}")
         elif function != "count" and field is None:
-            raise APIError("Function {0} requires a field value".format(
-                function))
-        elif function == 'to_string' and fmt is None:
+            raise APIError("Function {} requires a field value".format(function))
+        elif function == "to_string" and fmt is None:
             raise APIError("Function {0} requires an extra 'fmt' parameter")
 
-        self.arr = ['function', function]
+        self.arr = ["function", function]
 
         if field is not None:
             self.arr.append(field)
 
-        if function == 'to_string':
+        if function == "to_string":
             self.arr.append(fmt)
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -217,7 +217,7 @@ class FunctionOperator(object):
         return self.arr
 
 
-class SubqueryOperator(object):
+class SubqueryOperator:
     """
     Performs a subquery to another puppetDB object, full
     documentation is available at
@@ -230,13 +230,22 @@ class SubqueryOperator(object):
     """
 
     def __init__(self, endpoint):
-        if endpoint not in ['catalogs', 'edges', 'environments', 'events',
-                            'facts', 'fact_contents', 'fact_paths', 'nodes',
-                            'reports', 'resources']:
-            raise APIError("Unsupported endpoint: {0}".format(endpoint))
+        if endpoint not in [
+            "catalogs",
+            "edges",
+            "environments",
+            "events",
+            "facts",
+            "fact_contents",
+            "fact_paths",
+            "nodes",
+            "reports",
+            "resources",
+        ]:
+            raise APIError(f"Unsupported endpoint: {endpoint}")
 
         self.query = None
-        self.arr = ['select_{0}'.format(endpoint)]
+        self.arr = [f"select_{endpoint}"]
 
     def add_query(self, query):
         if self.query is not None:
@@ -246,7 +255,7 @@ class SubqueryOperator(object):
             self.arr.append(query.json_data())
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -255,7 +264,7 @@ class SubqueryOperator(object):
         return self.arr
 
 
-class InOperator(object):
+class InOperator:
     """
     Performs boolean compare between a field a subquery result
     https://puppet.com/docs/puppetdb/7/api/query/v4/ast.html#subquery-operators
@@ -268,7 +277,7 @@ class InOperator(object):
 
     def __init__(self, field):
         self.query = None
-        self.arr = ['in', field]
+        self.arr = ["in", field]
 
     def add_query(self, query):
         if self.query is not None:
@@ -280,31 +289,39 @@ class InOperator(object):
             self.query = True
             self.arr.append(query.json_data())
         else:
-            raise APIError("InOperator.add_query only supports "
-                           "strings, ExtractOperator, and"
-                           "FromOperator objects")
+            raise APIError(
+                "InOperator.add_query only supports "
+                "strings, ExtractOperator, and"
+                "FromOperator objects"
+            )
 
     def add_array(self, values):
         if self.query is not None:
             raise APIError("Only one array is supported by the InOperator")
         elif isinstance(values, list):
+
             def depth(a_list):
-                return (isinstance(a_list, list) and len(a_list) != 0) \
-                       and max(map(depth, a_list)) + 1
+                return (isinstance(a_list, list) and len(a_list) != 0) and max(
+                    map(depth, a_list)
+                ) + 1
 
             if depth(values) == 1:
                 self.query = True
-                self.arr.append(['array', values])
+                self.arr.append(["array", values])
             else:
-                raise APIError("InOperator.add_array: cannot pass in "
-                               "nested arrays (or empty arrays)")
+                raise APIError(
+                    "InOperator.add_array: cannot pass in "
+                    "nested arrays (or empty arrays)"
+                )
         else:
-            raise APIError("InOperator.add_array: Ill-formatted array, "
-                           "must be of the format: "
-                           "['array', [<array values>]]")
+            raise APIError(
+                "InOperator.add_array: Ill-formatted array, "
+                "must be of the format: "
+                "['array', [<array values>]]"
+            )
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -313,7 +330,7 @@ class InOperator(object):
         return self.arr
 
 
-class FromOperator(object):
+class FromOperator:
     """
     From contextual operator that allows for queries on the root endpoint
     or subqueries into other entities:
@@ -329,17 +346,30 @@ class FromOperator(object):
     """
 
     def __init__(self, endpoint):
-        valid_entities = ["aggregate_event_counts", "catalogs", "edges",
-                          "environments", "event_counts", "events", "facts",
-                          "fact_contents", "fact_names", "fact_paths", "nodes",
-                          "producers", "reports", "resources"]
+        valid_entities = [
+            "aggregate_event_counts",
+            "catalogs",
+            "edges",
+            "environments",
+            "event_counts",
+            "events",
+            "facts",
+            "fact_contents",
+            "fact_names",
+            "fact_paths",
+            "nodes",
+            "producers",
+            "reports",
+            "resources",
+        ]
 
         if endpoint in valid_entities:
             self.endpoint = endpoint
         else:
-            raise APIError("Endpoint is invalid. Must be "
-                           "one of the following : %s"
-                           % valid_entities)
+            raise APIError(
+                "Endpoint is invalid. Must be "
+                "one of the following : %s" % valid_entities
+            )
 
         self.query = None
         self.order_by = []
@@ -349,13 +379,19 @@ class FromOperator(object):
     def add_query(self, query):
         if self.query is not None:
             raise APIError("Only one main query is supported by FromOperator")
-        elif isinstance(query, (InOperator, ExtractOperator,
-                                BinaryOperator, BooleanOperator,
-                                FunctionOperator)):
+        elif isinstance(
+            query,
+            (
+                InOperator,
+                ExtractOperator,
+                BinaryOperator,
+                BooleanOperator,
+                FunctionOperator,
+            ),
+        ):
             self.query = query.json_data()
         else:
-            raise APIError("FromOperator.add_field only supports "
-                           "Operator Objects")
+            raise APIError("FromOperator.add_field only supports " "Operator Objects")
 
     def add_order_by(self, fields):
         def depth(a_list):
@@ -367,13 +403,17 @@ class FromOperator(object):
             if fields_depth == 1 or fields_depth == 2:
                 self.order_by = fields
             else:
-                raise APIError("ExtractOperator.add_order_by only "
-                               "supports lists of fields of depth "
-                               "one or two: [value, <desc/asc>] or "
-                               "[value]")
+                raise APIError(
+                    "ExtractOperator.add_order_by only "
+                    "supports lists of fields of depth "
+                    "one or two: [value, <desc/asc>] or "
+                    "[value]"
+                )
         else:
-            raise APIError("ExtractOperator.add_group_by only supports "
-                           "lists of one or more fields")
+            raise APIError(
+                "ExtractOperator.add_group_by only supports "
+                "lists of one or more fields"
+            )
 
     def add_limit(self, lim):
         if isinstance(lim, int):
@@ -388,7 +428,7 @@ class FromOperator(object):
             raise APIError("ExtractOperator.add_offset only supports ints")
 
     def __repr__(self):
-        return 'Query: {0}'.format(self)
+        return f"Query: {self}"
 
     def __str__(self):
         return json.dumps(self.json_data())
@@ -397,14 +437,14 @@ class FromOperator(object):
         if self.query is None:
             raise APIError("FromOperator needs one main query")
 
-        arr = ['from', self.endpoint, self.query]
+        arr = ["from", self.endpoint, self.query]
 
         if len(self.order_by) > 0:
-            arr.append(['order_by', self.order_by])
+            arr.append(["order_by", self.order_by])
         if self.limit is not None:
-            arr.append(['limit', self.limit])
+            arr.append(["limit", self.limit])
         if self.offset is not None:
-            arr.append(['offset', self.offset])
+            arr.append(["offset", self.offset])
 
         return arr
 
@@ -431,7 +471,7 @@ class EqualsOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(EqualsOperator, self).__init__("=", field, value)
+        super().__init__("=", field, value)
 
 
 class GreaterOperator(BinaryOperator):
@@ -456,7 +496,7 @@ class GreaterOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(GreaterOperator, self).__init__(">", field, value)
+        super().__init__(">", field, value)
 
 
 class LessOperator(BinaryOperator):
@@ -481,7 +521,7 @@ class LessOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(LessOperator, self).__init__("<", field, value)
+        super().__init__("<", field, value)
 
 
 class GreaterEqualOperator(BinaryOperator):
@@ -507,7 +547,7 @@ class GreaterEqualOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(GreaterEqualOperator, self).__init__(">=", field, value)
+        super().__init__(">=", field, value)
 
 
 class LessEqualOperator(BinaryOperator):
@@ -533,7 +573,7 @@ class LessEqualOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(LessEqualOperator, self).__init__("<=", field, value)
+        super().__init__("<=", field, value)
 
 
 class RegexOperator(BinaryOperator):
@@ -558,7 +598,7 @@ class RegexOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(RegexOperator, self).__init__("~", field, value)
+        super().__init__("~", field, value)
 
 
 class RegexArrayOperator(BinaryOperator):
@@ -584,7 +624,7 @@ class RegexArrayOperator(BinaryOperator):
     """
 
     def __init__(self, field, value):
-        super(RegexArrayOperator, self).__init__("~>", field, value)
+        super().__init__("~>", field, value)
 
 
 class NullOperator(BinaryOperator):
@@ -615,7 +655,7 @@ class NullOperator(BinaryOperator):
         if type(value) != bool:
             raise APIError("NullOperator value must be boolean")
 
-        super(NullOperator, self).__init__("null?", field, value)
+        super().__init__("null?", field, value)
 
 
 class AndOperator(BooleanOperator):
@@ -639,7 +679,7 @@ class AndOperator(BooleanOperator):
     """
 
     def __init__(self):
-        super(AndOperator, self).__init__("and")
+        super().__init__("and")
 
 
 class OrOperator(BooleanOperator):
@@ -661,7 +701,7 @@ class OrOperator(BooleanOperator):
     """
 
     def __init__(self):
-        super(OrOperator, self).__init__("or")
+        super().__init__("or")
 
 
 class NotOperator(BooleanOperator):
@@ -685,11 +725,11 @@ class NotOperator(BooleanOperator):
     """
 
     def __init__(self):
-        super(NotOperator, self).__init__("not")
+        super().__init__("not")
 
     def add(self, query):
         if len(self.operations) > 0:
             raise APIError("This operator only accept one query string")
         elif isinstance(query, list) and len(query) > 1:
             raise APIError("This operator only accept one query string")
-        super(NotOperator, self).add(query)
+        super().add(query)
