@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import logging
 
 from pypuppetdb.api.base import BaseAPI
@@ -19,4 +16,4 @@ class StatusAPI(BaseAPI):
         :returns: A dict with the PuppetDB status information
         :rtype: :obj:`dict`
         """
-        return self._query('status')
+        return self._query("status")
